Name:       cswrap
Version:    1.3.2
Release:    1%{?dist}
Summary:    Generic compiler wrapper

Group:      Development/Tools
License:    GPLv3+
URL:        https://git.fedorahosted.org/cgit/%{name}.git
Source0:    https://git.fedorahosted.org/cgit/%{name}.git/snapshot/%{name}-%{version}.tar.xz

# cswrap-1.3.0+ emits internal warnings per timed out scans (used by csdiff to
# eliminate false positivies that such a scan would otherwise cause) ==> force
# new enough versions of the higher-level tools that will suppress them.
Conflicts: csbuild       < 1.7.0
Conflicts: csdiff        < 1.2.0
Conflicts: csmock-common < 1.7.0

BuildRequires: asciidoc
BuildRequires: cmake

# The test-suite runs automatically trough valgrind if valgrind is available
# on the system.  By not installing valgrind into mock's chroot, we disable
# this feature for production builds on architectures where valgrind is known
# to be less reliable, in order to avoid unnecessary build failures (see RHBZ
# #810992, #816175, and #886891).  Nevertheless developers are free to install
# valgrind manually to improve test coverage on any architecture.
%ifarch %{ix86} x86_64
BuildRequires: valgrind
%endif

# csmock copies the resulting cswrap binary into mock chroot, which may contain
# an older (e.g. RHEL-5) version of glibc, and it would not dynamically link
# against the old version of glibc if it was built against a newer one.
# Therefor we link glibc statically.
%if (0%{?fedora} >= 12 || 0%{?rhel} >= 6)
BuildRequires: glibc-static
%endif

%description
Generic compiler wrapper used by csmock to capture diagnostic messages.

%prep
%setup -q

%build
mkdir cswrap_build
cd cswrap_build
export CFLAGS="$RPM_OPT_FLAGS"' -DPATH_TO_WRAP=\"%{_libdir}/cswrap\"'
export LDFLAGS="$RPM_OPT_FLAGS -static -pthread"
%cmake ..
make %{?_smp_mflags} VERBOSE=yes

%check
cd cswrap_build
ctest %{?_smp_mflags} --output-on-failure

%install
cd cswrap_build
make install DESTDIR="$RPM_BUILD_ROOT"

install -m0755 -d "$RPM_BUILD_ROOT%{_libdir}"{,/cswrap}
for i in c++ cc g++ gcc clang clang++ cppcheck \
    %{_arch}-redhat-linux-c++ \
    %{_arch}-redhat-linux-g++ \
    %{_arch}-redhat-linux-gcc
do
    ln -s ../../bin/cswrap "$RPM_BUILD_ROOT%{_libdir}/cswrap/$i"
done

%files
%{_bindir}/cswrap
%{_libdir}/cswrap
%{_mandir}/man1/%{name}.1*
%doc COPYING README

%changelog
* Mon Mar 21 2016 Kamil Dudka <kdudka@redhat.com> 1.3.2-1
- update to latest upstream

* Wed Feb 03 2016 Kamil Dudka <kdudka@redhat.com> 1.3.1-1
- update to latest upstream

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Feb 18 2015 Kamil Dudka <kdudka@redhat.com> 1.3.0-1
- update to latest upstream

* Mon Jan 19 2015 Kamil Dudka <kdudka@redhat.com> 1.2.1-1
- update to latest upstream

* Thu Nov 06 2014 Kamil Dudka <kdudka@redhat.com> 1.2.0-1
- update to latest upstream

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Aug 01 2014 Kamil Dudka <kdudka@redhat.com> 1.0.5-1
- update to latest upstream

* Thu Jul 17 2014 Kamil Dudka <kdudka@redhat.com> 1.0.4-1
- update to latest upstream

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Mar 27 2014 Kamil Dudka <kdudka@redhat.com> 1.0.3-1
- update to latest upstream

* Mon Mar 10 2014 Kamil Dudka <kdudka@redhat.com> 1.0.2-2
- abandon RHEL-5 compatibility (#1066028)

* Wed Feb 19 2014 Kamil Dudka <kdudka@redhat.com> 1.0.2-1
- packaged for Fedora
